==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/EgressNetworkPolicySpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EgressNetworkPolicySpecFluent<A extends io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEgress(java.lang.Integer index,io.fabric8.openshift.api.model.EgressNetworkPolicyRule item);
  public A setToEgress(java.lang.Integer index,io.fabric8.openshift.api.model.EgressNetworkPolicyRule item);
  public A addToEgress(io.fabric8.openshift.api.model.EgressNetworkPolicyRule... items);
  public A addAllToEgress(java.util.Collection<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> items);
  public A removeFromEgress(io.fabric8.openshift.api.model.EgressNetworkPolicyRule... items);
  public A removeAllFromEgress(java.util.Collection<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> items);
  public A removeMatchingFromEgress(java.util.function.Predicate<io.fabric8.openshift.api.model.EgressNetworkPolicyRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildEgress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> getEgress();
  public java.util.List<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> buildEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicyRule buildEgress(java.lang.Integer index);
  public io.fabric8.openshift.api.model.EgressNetworkPolicyRule buildFirstEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicyRule buildLastEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicyRule buildMatchingEgress(java.util.function.Predicate<io.fabric8.openshift.api.model.EgressNetworkPolicyRuleBuilder> predicate);
  public java.lang.Boolean hasMatchingEgress(java.util.function.Predicate<io.fabric8.openshift.api.model.EgressNetworkPolicyRuleBuilder> predicate);
  public A withEgress(java.util.List<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> egress);
  public A withEgress(io.fabric8.openshift.api.model.EgressNetworkPolicyRule... egress);
  public java.lang.Boolean hasEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> addNewEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> addNewEgressLike(io.fabric8.openshift.api.model.EgressNetworkPolicyRule item);
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> setNewEgressLike(java.lang.Integer index,io.fabric8.openshift.api.model.EgressNetworkPolicyRule item);
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> editEgress(java.lang.Integer index);
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> editFirstEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> editLastEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> editMatchingEgress(java.util.function.Predicate<io.fabric8.openshift.api.model.EgressNetworkPolicyRuleBuilder> predicate);
  public interface EgressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.EgressNetworkPolicyRuleFluent<io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<N>>{
    public N and();
    public N endEgress();
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/EgressNetworkPolicySpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EgressNetworkPolicySpecFluent<A extends io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEgress(java.lang.Integer index,io.fabric8.openshift.api.model.EgressNetworkPolicyRule item);
  public A setToEgress(java.lang.Integer index,io.fabric8.openshift.api.model.EgressNetworkPolicyRule item);
  public A addToEgress(io.fabric8.openshift.api.model.EgressNetworkPolicyRule... items);
  public A addAllToEgress(java.util.Collection<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> items);
  public A removeFromEgress(io.fabric8.openshift.api.model.EgressNetworkPolicyRule... items);
  public A removeAllFromEgress(java.util.Collection<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> items);
  public A removeMatchingFromEgress(java.util.function.Predicate<io.fabric8.openshift.api.model.EgressNetworkPolicyRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildEgress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> getEgress();
  public java.util.List<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> buildEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicyRule buildEgress(java.lang.Integer index);
  public io.fabric8.openshift.api.model.EgressNetworkPolicyRule buildFirstEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicyRule buildLastEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicyRule buildMatchingEgress(java.util.function.Predicate<io.fabric8.openshift.api.model.EgressNetworkPolicyRuleBuilder> predicate);
  public java.lang.Boolean hasMatchingEgress(java.util.function.Predicate<io.fabric8.openshift.api.model.EgressNetworkPolicyRuleBuilder> predicate);
  public A withEgress(java.util.List<io.fabric8.openshift.api.model.EgressNetworkPolicyRule> egress);
  public A withEgress(io.fabric8.openshift.api.model.EgressNetworkPolicyRule... egress);
  public java.lang.Boolean hasEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> addNewEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> addNewEgressLike(io.fabric8.openshift.api.model.EgressNetworkPolicyRule item);
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> setNewEgressLike(java.lang.Integer index,io.fabric8.openshift.api.model.EgressNetworkPolicyRule item);
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> editEgress(java.lang.Integer index);
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> editFirstEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> editLastEgress();
  public io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<A> editMatchingEgress(java.util.function.Predicate<io.fabric8.openshift.api.model.EgressNetworkPolicyRuleBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface EgressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.EgressNetworkPolicyRuleFluent<io.fabric8.openshift.api.model.EgressNetworkPolicySpecFluent.EgressNested<N>>{
    public N and();
    public N endEgress();
    
  }
  
}
